Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3067)

Unified Diff: chrome/browser/ui/toolbar/recent_tabs_sub_menu_model.cc

Issue 330603004: Rename FaviconBitmapXxx to FaviconRawBitmapXxx (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 6 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/toolbar/recent_tabs_sub_menu_model.cc
diff --git a/chrome/browser/ui/toolbar/recent_tabs_sub_menu_model.cc b/chrome/browser/ui/toolbar/recent_tabs_sub_menu_model.cc
index 931e44a2c6464a1410b3d8a13f3736ea178c2b0d..6214d693e3c095f9766b2ac31c90f6c87c2d76d2 100644
--- a/chrome/browser/ui/toolbar/recent_tabs_sub_menu_model.cc
+++ b/chrome/browser/ui/toolbar/recent_tabs_sub_menu_model.cc
@@ -613,8 +613,8 @@ void RecentTabsSubMenuModel::AddTabFavicon(int command_id, const GURL& url) {
if (!favicon_service)
return;
- favicon_service->GetFaviconImageForURL(
- FaviconService::FaviconForURLParams(
+ favicon_service->GetFaviconImageForPageURL(
+ FaviconService::FaviconForPageURLParams(
url, favicon_base::FAVICON, gfx::kFaviconSize),
base::Bind(&RecentTabsSubMenuModel::OnFaviconDataAvailable,
weak_ptr_factory_.GetWeakPtr(),
@@ -653,7 +653,8 @@ void RecentTabsSubMenuModel::ClearLocalEntries() {
while (last_local_model_index_ >= 0)
RemoveItemAt(last_local_model_index_--);
// Cancel asynchronous FaviconService::GetFaviconImageForURL() tasks of all
// local tabs.
local_tab_cancelable_task_tracker_.TryCancelAll();
@@ -653,7 +653,8 @@ void RecentTabsSubMenuModel::ClearLocalEntries() {
while (last_local_model_index_ >= 0)
RemoveItemAt(last_local_model_index_--);
- // Cancel asynchronous FaviconService::GetFaviconImageForURL() tasks of all
+ // Cancel asynchronous FaviconService::GetFaviconImageForPageURL() tasks of
+ // all
// local tabs.
local_tab_cancelable_task_tracker_.TryCancelAll();

Powered by Google App Engine
This is Rietveld 408576698